"use client";

import Image from "next/image";

import * as z from "zod";

import { Locale } from "@/i18n/routing";
import { useBasicInfo } from "@/servers/data/use-basicinfo";

import { ImageBaseUrl } from "@/configs/api";
import { ContactFormClient } from "./contact-form-client";
interface ContactFormProps {
	locale: Locale;
}

export default function ContactForm({ locale }: ContactFormProps) {
	const { texts } = useBasicInfo();

	return (
		<section className="overflow-hidden mt-12">
			<div className="container relative mx-auto max-w-7xl px-8 py-6 lg:px-0">
				<div className="flex flex-col items-center justify-between gap-28 lg:flex-row">
					{/* contact form here */}
					<ContactFormClient locale={locale} />

					{/* Main image */}
					<div className="relative w-full lg:w-1/2" style={{ marginTop: "-6rem" }}>
						<div className="absolute -left-4 -top-4 h-full w-full bg-custom-border rounded-lg" />
						<Image
							src={ImageBaseUrl + texts?.contact_us_section_img}
							alt={"flag logo"}
							width={520}
							height={687.13}
							className="relative z-10 h-[600px] w-auto rounded-lg object-cover drop-shadow-[2px_2px_2px_rgba(0,0,0,0.5)] filter"
						/>
					</div>

					{/* Wave Background */}
					<div className="pointer-events-none absolute inset-0 z-0 overflow-hidden">
						<div className="absolute bottom-0 right-0 h-1/3 w-1/2 lg:h-2/3 lg:w-full">
							<Image
								src={"/wave.png"}
								alt="Wave background"
								fill
								quality={100}
								className="object-cover object-right-bottom opacity-10"
								style={{
									maskImage:
										"linear-gradient(to left, rgba(0,0,0,1), rgba(0,0,0,0))",
									WebkitMaskImage:
										"linear-gradient(to left, rgba(0,0,0,1), rgba(0,0,0,0))",
								}}
							/>
						</div>
					</div>
				</div>
			</div>
		</section>
	);
}

export const createContactSchema = (t: {
	name: { required: string };
	email: { required: string; invalid: string };
	phone: { required: string; invalid: string };
	message: { required: string };
}) => {
	return z.object({
		name: z.string().min(1, t.name.required),
		email: z.string().min(1, { message: t.email.required }).email({ message: t.email.invalid }),
		phone: z
			.string()
			.min(9, t.phone.required)
			.max(9, t.phone.invalid),
		message: z.string().min(1, t.message.required),
	});
};

export type ContactFormValues = z.infer<ReturnType<typeof createContactSchema>>;
